@@ -1,3 +1,4 @@
+import requests
 import urllib.parse
 import asyncio
 import aio_pika
@@ -51,6 +52,28 @@ class AIORabbitMQ:
         """Disconnect RabbitMQ connection
         """
         await self.connection.close()
+    
+    async def get_list_queues(self, user: str = 'guest',
+                              password: str = 'guest',
+                              host: str = 'localhost',
+                              port: int = 15672,
+                              virtual_host: str = None) -> list:
+        """Get list all queues using RabbitMQ Management API
+
+        Args:
+            user (str, optional): RabbitMQ user. Defaults to 'guest'.
+            password (str, optional): RabbitMQ password. Defaults to 'guest'.
+            host (str, optional): RabbitMQ host. Defaults to 'localhost'.
+            port (int, optional): RabbitMQ port. Defaults to 15672.
+            virtual_host (str, optional): RabbitMQ virtual host. Defaults to None.
+
+        Returns:
+            list: List of queues
+        """
+        url = 'http://%s:%s/api/queues/%s' % (host, port, virtual_host or '')
+        response = requests.get(url, auth=(user, password))
+        queues = [q['name'] for q in response.json()]
+        return queues
 
     async def send(self, queue: str, body: MessagePayload, exchange: str = '') -> None:
         """Send message/body to RabbitMQ channel queue
@@ -60,7 +83,11 @@ class AIORabbitMQ:
             body (MessagePayload): Message/body payload
             exchange (str, optional): Exchange name. Defaults to ''
         """
-        await self.channel.declare_queue(queue, durable=self.durable, auto_delete=self.auto_delete)
+        try:
+            await self.channel.get_queue(queue, ensure=True)
+        except:
+            await self.channel.reopen()
+            await self.channel.declare_queue(queue, durable=self.durable, auto_delete=self.auto_delete)
         if exchange == '':
             await self.channel.default_exchange.publish(
                 aio_pika.Message(
@@ -70,7 +97,11 @@ class AIORabbitMQ:
                 queue,
             )
         else:
-            exchange = await self.channel.declare_exchange(exchange, auto_delete=self.auto_delete)
+            try:
+                exchange = await self.channel.get_exchange(exchange)
+            except:
+                await self.channel.reopen()
+                exchange = await self.channel.declare_exchange(exchange, auto_delete=self.auto_delete)
             await exchange.publish(
                 aio_pika.Message(
                     bytes(str(body), 'utf-8'),
@@ -90,7 +121,11 @@ class AIORabbitMQ:
             queue (str): Queue name
             callback (Callable[ [ aio_pika.IncomingMessage ], None ]): Callback to be called after receiving a message
         """
-        queue = await self.channel.declare_queue(queue, durable=self.durable, auto_delete=self.auto_delete)
+        try:
+            queue = await self.channel.get_queue(queue, ensure=True)
+        except:
+            await self.channel.reopen()
+            queue = await self.channel.declare_queue(queue, durable=self.durable, auto_delete=self.auto_delete)
         await queue.consume(callback, no_ack=self.auto_ack)
 
     async def delete_queue(self, queue: str) -> None:
